@@ -1,25 +1,15 @@
-#' Uses the addition function "+" to combine two vectors setting NA values of the first vector to zero.
-#'
-#' Uses the addition function "+" to combine two vectors setting NA values of the first vector to zero.
-#'
-#' @param x a vector.
-#' @param y vector to combine with.
-#'
-#' @return dataframe with additional columns "from" and "to".
-#'
-#' @examples
-#'
-#' #summentest=summe(c(1,2,NA,4),c(5,6,7,8)
-#'
-#' @keywords internal
-
-summe=function(x,y){
-  if(any(is.na(x))){
-    x[is.na(x)]=0
-  }
-  return(x+y)
+`%+0%` <- function(x, y) {
+  x <- NA_to_0(x)
+  y <- NA_to_0(y)
+  return(x + y)
 }
 
+NA_to_0 <- function(x) {
+  if (any(is.na(x))) {
+    x[is.na(x)] <- 0
+  }
+  return(x)
+}
 
 #' Creates the input for the function life.table.
 #'
@@ -40,7 +30,7 @@ summe=function(x,y){
 #' optional. Default setup is: \code{NA}.
 #' @param method character string, optional. Default options is \code{Standard}, which will create age classes beginning with 1 year,
 #' up to 4 years, followed by steps of 5 years (1,4,5,5,...) until the maximum age is reached. \code{Equal5} will create age classes with an even distribution, stepped by 5 years (5,5,...) until the maximum age is reached.
-#' @param agerange character string, optional. Default setup is: \code{excluded}.
+#' @param agerange character string, optional. Default setup is: \code{included}.
 #' If the age ranges from "20 to 40" and "40 to 60", \code{excluded} will exclude the year 40 from "20 to 40",
 #' to  prevent overlapping age classes. \code{included} is for age ranges like "20 to 39"
 #' where the year 39 is meant to be counted.
@@ -147,12 +137,12 @@ prep.life.table=function(x, dec = NA, agebeg, ageend, group = NA, method = "Stan
     # For each Group (k) the deaths per age class (available years i) are summed up equally seperated by ages.
     for(k in 1:length(unique(asd$Group))){
       for(i in which(asd$Group==unique(asd$Group)[k])){
-        restab[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1)),(k+1)]=summe(x=(restab[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1)),(k+1)]),y=(asd$cof[i]/(length(seq(asd$beg[i],asd$ende[i],1)))))
+        restab[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1)),(k+1)] <- restab[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1)),(k+1)] %+0% (asd$cof[i]/(length(seq(asd$beg[i],asd$ende[i],1))))
       }
     }
     # Also for all Groups all deceased are summed up seperated according to the years.
     for(i in seq_along(asd[,1])){
-      restab$All[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1))]=summe(x=(restab$All[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1))]),y=(asd$cof[i]/(length(seq(asd$beg[i],asd$ende[i],1)))))
+      restab$All[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1))] <- (restab$All[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1))]) %+0% (asd$cof[i]/(length(seq(asd$beg[i],asd$ende[i],1))))
     }
 
     # If no groups (male, female, phase, ...) are specified, do the same without considering groups.
@@ -161,7 +151,7 @@ prep.life.table=function(x, dec = NA, agebeg, ageend, group = NA, method = "Stan
     restab=data.frame(Age=seq(0,99,1),Deceased=0)
 
     for(i in seq_along(asd[,1])){
-      restab$Deceased[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1))]=summe(x=(restab$Deceased[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1))]),y=(asd$cof[i]/(length(seq(asd$beg[i],asd$ende[i],1)))))
+      restab$Deceased[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1))] <- (restab$Deceased[is.element(restab$Age,seq(asd$beg[i],asd$ende[i],1))]) %+0% (asd$cof[i]/(length(seq(asd$beg[i],asd$ende[i],1))))
     }
   }
 
